==> keycloak-model-map-hot-rod-19.0.0-sources.jar: org/keycloak/models/map/storage/hotRod/userSession/HotRodAuthenticatedClientSessionEntityDescriptor.java <==
package org.keycloak.models.map.storage.hotRod.userSession;
import org.infinispan.protostream.GeneratedSchema;
import java.util.function.Function;
public class HotRodAuthenticatedClientSessionEntityDescriptor implements org.keycloak.models.map.storage.hotRod.common.HotRodEntityDescriptor<org.keycloak.models.map.storage.hotRod.userSession.HotRodAuthenticatedClientSessionEntity, org.keycloak.models.map.storage.hotRod.userSession.HotRodAuthenticatedClientSessionEntityDelegate> {
    @Override
    public Class<?> getModelTypeClass() {
        return org.keycloak.models.AuthenticatedClientSessionModel.class;
    }
    @Override
    public Class<org.keycloak.models.map.storage.hotRod.userSession.HotRodAuthenticatedClientSessionEntity> getEntityTypeClass() {
        return org.keycloak.models.map.storage.hotRod.userSession.HotRodAuthenticatedClientSessionEntity.class;
    }
    @Override
    public String getCacheName() {
        return org.keycloak.models.map.storage.ModelEntityUtil.getModelName(org.keycloak.models.UserSessionModel.class);
    }
    @Override
    public Function<org.keycloak.models.map.storage.hotRod.userSession.HotRodAuthenticatedClientSessionEntity, org.keycloak.models.map.storage.hotRod.userSession.HotRodAuthenticatedClientSessionEntityDelegate> getHotRodDelegateProvider() {
        return org.keycloak.models.map.storage.hotRod.userSession.HotRodAuthenticatedClientSessionEntityDelegate::new;
    }
    @Override
    public Integer getCurrentVersion() {
        return org.keycloak.models.map.storage.hotRod.userSession.HotRodAuthenticatedClientSessionEntity.VERSION;
    }
    @Override
    public GeneratedSchema getProtoSchema() {
        return org.keycloak.models.map.storage.hotRod.userSession.HotRodAuthenticatedClientSessionEntity.HotRodAuthenticatedClientSessionEntitySchema.INSTANCE;
    }
}

==> keycloak-model-map-hot-rod-22.0.5-sources.jar: org/keycloak/models/map/storage/hotRod/userSession/HotRodAuthenticatedClientSessionEntityDescriptor.java <==
package org.keycloak.models.map.storage.hotRod.userSession;
import org.infinispan.protostream.GeneratedSchema;
import java.util.function.Function;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateHotRodEntityImplementationsProcessor")
public class HotRodAuthenticatedClientSessionEntityDescriptor implements org.keycloak.models.map.storage.hotRod.common.HotRodEntityDescriptor<org.keycloak.models.map.storage.hotRod.userSession.HotRodAuthenticatedClientSessionEntity, org.keycloak.models.map.storage.hotRod.userSession.HotRodAuthenticatedClientSessionEntityDelegate> {
    @Override
    public Class<?> getModelTypeClass() {
        return org.keycloak.models.AuthenticatedClientSessionModel.class;
    }
    @Override
    public Class<org.keycloak.models.map.storage.hotRod.userSession.HotRodAuthenticatedClientSessionEntity> getEntityTypeClass() {
        return org.keycloak.models.map.storage.hotRod.userSession.HotRodAuthenticatedClientSessionEntity.class;
    }
    @Override
    public String getCacheName() {
        return org.keycloak.models.map.storage.ModelEntityUtil.getModelName(org.keycloak.models.UserSessionModel.class);
    }
    @Override
    public Function<org.keycloak.models.map.storage.hotRod.userSession.HotRodAuthenticatedClientSessionEntity, org.keycloak.models.map.storage.hotRod.userSession.HotRodAuthenticatedClientSessionEntityDelegate> getHotRodDelegateProvider() {
        return org.keycloak.models.map.storage.hotRod.userSession.HotRodAuthenticatedClientSessionEntityDelegate::new;
    }
    @Override
    public Integer getCurrentVersion() {
        return org.keycloak.models.map.storage.hotRod.userSession.HotRodAuthenticatedClientSessionEntity.VERSION;
    }
    @Override
    public GeneratedSchema getProtoSchema() {
        return org.keycloak.models.map.storage.hotRod.userSession.HotRodAuthenticatedClientSessionEntity.HotRodAuthenticatedClientSessionEntitySchema.INSTANCE;
    }
}
